==> haskell-blaze-builder-0.4.0.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-builder.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-builder
version: 0.4.0.2
id: blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
key: blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
license: BSD3
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Leon Smith <leon@melding-monads.com>
stability: Experimental
homepage: http://github.com/lpsmith/blaze-builder
synopsis: Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0
    .
    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.
    .
    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.
category: Data
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
exposed: True
indefinite: False
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Compat.Write Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Internal.Write
    Blaze.ByteString.Builder.Word
abi: 9a0562647033c21b2abf88c991a65d08
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-builder-0.4.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-builder-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/blaze-builder-0.4.0.2
hs-libraries: HSblaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
depends:
    base-4.10.1.0 deepseq-1.4.3.0 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock
haddock-html: /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-builder-0.4.0.2-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-builder.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-builder
version: 0.4.0.2
id: blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
key: blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
license: BSD3
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
maintainer: Leon Smith <leon@melding-monads.com>
stability: Experimental
homepage: http://github.com/lpsmith/blaze-builder
synopsis: Efficient buffered output.
description:
    This library provides an implementation of the older
    blaze-builder interface in terms of the new builder that
    shipped with bytestring-0.10.4.0
    .
    This implementation is mostly intended as a bridge to the
    new builder,  so that code that uses the old interface
    can interoperate with code that uses the new
    implementation.   Note that no attempt has been made
    to preserve the old internal modules,  so code that
    has these dependencies cannot use this interface.
    .
    New code should,  for the most part,  use the new
    interface.   However, this module does implement
    a chunked HTTP encoding,  which is not otherwise
    implemented (yet?) with the new builder.
category: Data
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith
exposed: True
indefinite: False
exposed-modules:
    Blaze.ByteString.Builder Blaze.ByteString.Builder.ByteString
    Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
    Blaze.ByteString.Builder.Compat.Write Blaze.ByteString.Builder.HTTP
    Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.Int
    Blaze.ByteString.Builder.Internal.Write
    Blaze.ByteString.Builder.Word
abi: 4ded867b3c298ec132dad2104a7f7b70
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-builder-0.4.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-builder-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/blaze-builder-0.4.0.2
hs-libraries: HSblaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
depends:
    base-4.10.1.0 deepseq-1.4.3.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock
haddock-html: /usr/share/doc/haskell-blaze-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
